<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=fr_tu
// ** ne pas modifier le fichier **

return [

	// D
	'dist_description' => 'Jeu de squelettes distribué avec SPIP 3.',
	'dist_slogan' => 'Squelettes par défaut de SPIP 3',
];
